pub(crate) struct ChunkTicket {
ticket_type: TicketTypeRef,
ticket_level: ChunkTicketLevel,
ticks_left: i64,
}Expand description
One ticket type and level, with its remaining timeout.
Fields
ticket_type: TicketTypeRefticket_level: ChunkTicketLevelticks_left: i64Implementations
Sourceimpl ChunkTicket
impl ChunkTicket
Sourcepub(crate) const fn new(
ticket_type: TicketTypeRef,
ticket_level: ChunkTicketLevel,
) -> Self
pub(crate) const fn new( ticket_type: TicketTypeRef, ticket_level: ChunkTicketLevel, ) -> Self
Creates a ticket with the type’s full timeout.
Sourcepub(crate) const fn from_saved(
ticket_type: TicketTypeRef,
ticket_level: ChunkTicketLevel,
ticks_left: i64,
) -> Self
pub(crate) const fn from_saved( ticket_type: TicketTypeRef, ticket_level: ChunkTicketLevel, ticks_left: i64, ) -> Self
Restores a ticket’s serialized remaining timeout.
Sourcepub(crate) const fn for_full_chunk_radius(
ticket_type: TicketTypeRef,
radius: u8,
) -> Self
pub(crate) const fn for_full_chunk_radius( ticket_type: TicketTypeRef, radius: u8, ) -> Self
Creates a ticket that makes chunks full within radius.
pub(crate) const fn ticket_type(&self) -> TicketTypeRef
pub(crate) const fn ticket_level(&self) -> ChunkTicketLevel
pub(crate) const fn ticks_left(&self) -> i64
Sourcepub(crate) const fn loading_level(&self) -> Option<ChunkTicketLevel>
pub(crate) const fn loading_level(&self) -> Option<ChunkTicketLevel>
Returns this ticket’s contribution to loading propagation.
Sourcepub(crate) const fn simulation_level(&self) -> Option<ChunkTicketLevel>
pub(crate) const fn simulation_level(&self) -> Option<ChunkTicketLevel>
Returns this ticket’s contribution to simulation propagation.
Sourcepub(crate) const fn reset_ticks_left(&mut self)
pub(crate) const fn reset_ticks_left(&mut self)
Restores the type’s full timeout.
Sourcepub(crate) const fn decrease_ticks_left(&mut self)
pub(crate) const fn decrease_ticks_left(&mut self)
Ages a timed ticket by one tick using Java long overflow behavior.
pub(crate) const fn is_timed_out(&self) -> bool